@@ -21,13 +21,13 @@ import logging
 from os import path
 
 import click
+from click.core import Context
+from click.formatting import HelpFormatter
 
 from osducli.config import CLI_ENV_VAR_PREFIX, CLIConfig
 from osducli.log import get_logger
 from osducli.state import get_default_config
 
-# from osducli.util import is_help_command
-
 
 class State:  # pylint: disable=too-few-public-methods
     """Global state passed to all click commands"""
@@ -42,6 +42,50 @@ class State:  # pylint: disable=too-few-public-methods
     def __repr__(self):
         return f"State=Debug: {self.debug}, Config path: {self.config_path}"
 
+    def is_user_friendly_mode(self) -> bool:
+        """Return whether we are running in a user friendly output mode
+
+        Returns:
+            bool: whether running in user friendly mode
+        """
+        return self.output is None
+
+
+def _format_click_options(cmd: click.Command, ctx: Context, formatter: HelpFormatter) -> None:
+    """Writes options into the formatter split between Options and Common Options."""
+    opts = []
+    common_opts = []
+    for param in cmd.get_params(ctx):
+        _rv = param.get_help_record(ctx)
+        if _rv is not None:
+            if param.name in ["help", "debug", "config", "output", "query"]:
+                common_opts.append(_rv)
+            else:
+                opts.append(_rv)
+
+    if opts:
+        with formatter.section("Options"):
+            formatter.write_dl(opts)
+
+    if common_opts:
+        with formatter.section("Common Options"):
+            formatter.write_dl(common_opts)
+
+
+class CustomClickGroup(click.Group):
+    """Custom click.Group class providing customised help text"""
+
+    def format_options(self, ctx: Context, formatter: HelpFormatter) -> None:
+        _format_click_options(self, ctx, formatter)
+        self.format_commands(ctx, formatter)
+
+
+class CustomClickCommand(click.Command):
+    """Custom click.GrouCommand class providing customised help text"""
+
+    def format_options(self, ctx: Context, formatter: HelpFormatter) -> None:
+        _format_click_options(self, ctx, formatter)
+
 
 def global_params(func):
     """Handle global parameters setting to setup state and remove parameters from those passed
