@@ -36,6 +36,8 @@ MSG_HEADING_ENV_VARS = "\nEnvironment variables:"
 MSG_PROMPT_CONFIG = "\nWhat config file do you want to use as the default?"
 MSG_PROMPT_MANAGE_GLOBAL = "\nDo you wish to change your settings?"
 MSG_PROMPT_SERVER = "\nOSDU API Server []: "
+MSG_PROMPT_CRS_CATALOG_URL = "\nCRS Catalog API path []: "
+MSG_PROMPT_CRS_CONVERTER_URL = "\nCRS Converter API path []: "
 MSG_PROMPT_CONFIG_ENTITLEMENTS_URL = "\nEntitlements API path []: "
 MSG_PROMPT_FILE_URL = "\nFile API path []: "
 MSG_PROMPT_LEGAL_URL = "\nLegal API path []: "
